@@ -6,10 +6,10 @@ from .WebsocketListener import WebsocketListener
 
 class ZWaveMe:
     """Main controller class"""
-    def __init__(self, hass, config, domain="" logger=None, platforms=None, zwaveplatforms=None, ):
+    def __init__(self, hass, config, domain="", logger=None, platforms=None, zwaveplatforms=None):
         self._config = config
         
-        if logger = None:
+        if logger == None:
             logger = logging.getLogger(__name__)
         self._logger = logger
 
@@ -144,4 +144,4 @@ class ZWaveMe:
         return self._wshost
 
     async def async_update(self):
-        devices = self.update_devices()
+        devices = self.update_devices()
\ No newline at end of file
